bayespy.inference.vmp.nodes.expfamily.ExponentialFamilyDistribution
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. autoclass:: ExponentialFamilyDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~ExponentialFamilyDistribution.compute_cgf_from_parents
      ~ExponentialFamilyDistribution.compute_fixed_moments_and_f
      ~ExponentialFamilyDistribution.compute_logpdf
      ~ExponentialFamilyDistribution.compute_mask_to_parent
      ~ExponentialFamilyDistribution.compute_message_to_parent
      ~ExponentialFamilyDistribution.compute_moments_and_cgf
      ~ExponentialFamilyDistribution.compute_phi_from_parents
      ~ExponentialFamilyDistribution.plates_from_parent
      ~ExponentialFamilyDistribution.plates_to_parent
      ~ExponentialFamilyDistribution.random
   
   

   
   
   